# dawnet-client
Bring Your Own Audio Compute


LOCAL TEST:
`pip uninstall dawnet-client -y && pip install . && python ./run_dawnet.py dc308761-9aeb-4667-bb71-f11d87fec665`

LOCAL DEV:
```
export DAWNET_API_BASE_URL='http://localhost:8000'
export DAWNET_SOCKET_IP='0.0.0.0'
export DAWNET_SOCKET_PORT='8765'
```
